@@ -1,19 +1,18 @@
 /*
- *   Copyright (c) 2007-2009  Stefan Böhmann <kde@hilefoks.org>
+ * Copyright 2007-2009 by Stefan Böhmann <kde@hilefoks.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "settings.h"
 
@@ -49,12 +48,17 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
 {
     setCaption( i18n( "Configure Tea Cooker" ) );
 
-    setButtons( Ok | Cancel | Help );
+    setButtons( Ok | Cancel | Help | Reset );
+    setButtonText( KDialog::Reset, i18n( "Configure &amp;Notifications..." ) );
+    setButtonToolTip( KDialog::Reset,  i18n( "Configure notifications" ) );
+    setButtonIcon( KDialog::Reset, KIcon( "preferences-desktop-notification" ) );
+
     setHelp( "configure" );
 
     setButtonWhatsThis( KDialog::Ok,     i18n( "Save changes and close dialog." ) );
     setButtonWhatsThis( KDialog::Cancel, i18n( "Close dialog without saving changes." ) );
     setButtonWhatsThis( KDialog::Help,   i18n( "Show help page for this dialog." ) );
+    setButtonWhatsThis( KDialog::Reset,  i18n( "Configure notifications" ) );
 
     ui = new SettingsUI( this );
     setMainWidget( ui );
@@ -72,7 +76,6 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
     x = qMin( qMax( 0, y ), desktop.screenGeometry().height() - height() );
     move( QPoint( x, y ) );
 
-    bool noti=group.readEntry( "UseNotification", true );
     bool popup=group.readEntry( "UsePopup", true );
     bool autohide=group.readEntry( "PopupAutoHide", false );
     int autohidetime=group.readEntry( "PopupAutoHideTime", 30 );
@@ -80,7 +83,6 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
     int remindertime=group.readEntry( "ReminderTime", 60 );
     bool vis=group.readEntry( "UseVisualize", true );
 
-    ui->notificationCheckBox->setChecked( noti );
     ui->popupCheckBox->setChecked( popup );
     ui->autohideCheckBox->setChecked( autohide );
     ui->reminderCheckBox->setChecked( reminder );
@@ -91,7 +93,6 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
     ui->autohideSpinBox->setSuffix( ki18ncp( "Auto hide popup after", " second", " seconds") );
     ui->reminderSpinBox->setSuffix( ki18ncp( "Reminder every", " second", " seconds") );
 
-    ui->notificationButton->setEnabled( noti );
     ui->autohideCheckBox->setEnabled( popup );
     ui->autohideSpinBox->setEnabled( autohide );
     ui->reminderSpinBox->setEnabled( reminder );
@@ -112,7 +113,7 @@ SettingsDialog::SettingsDialog(TopLevel *toplevel, const QList<Tea> &teas)
     ui->downButton->setIcon( KIcon( "arrow-down" ) );
 
     connect( ui->popupCheckBox, SIGNAL( toggled(bool) ), this, SLOT( checkPopupButtonState(bool) ) );
-    connect( ui->notificationButton, SIGNAL( clicked() ), this, SLOT( confButtonClicked() ) );
+    connect( this, SIGNAL( resetClicked() ), this, SLOT( confButtonClicked() ) );
 
     connect( ui->newButton, SIGNAL( clicked() ), this, SLOT(newButtonClicked()) );
     connect( ui->removeButton, SIGNAL( clicked() ), this, SLOT(removeButtonClicked()) );
@@ -142,7 +143,6 @@ void SettingsDialog::accept()
     hide();
     saveDialogSize(group);
 
-    group.writeEntry( "UseNotification",   ui->notificationCheckBox->checkState() == Qt::Checked );
     group.writeEntry( "UsePopup",          ui->popupCheckBox->checkState() == Qt::Checked );
     group.writeEntry( "PopupAutoHide",     ui->autohideCheckBox->checkState() == Qt::Checked );
     group.writeEntry( "PopupAutoHideTime", ui->autohideSpinBox->value() );
